'
'  comm.bas - program to show communication between the controller and the
'  oscilloscope
'
'  Version: 1.2.
'
'REM $INCLUDE: 'decl.bas'

'
'  Allocate the buffers and initialize the port for input and output.
'  Assign a unique identifier to the port and store in variable SCOPE.
'
    CLS
    PRINT : PRINT "        TDS 200 Series COMM Program - Version 1.2"
    PRINT : PRINT
    PRINT "   ***  RS-232 parameters should be set to default values:"
    PRINT
    PRINT "          Baud Rate: 9600      EOL: LF        Delay: 0 s"
    PRINT "          Hard Flagging: On    Parity: None"
    PRINT "          Soft Flagging: Off   Stop Bits: 1"
    PRINT
    PRINT "        These parameters can be changed in the "
    PRINT "        UTILITY  System - I/O  RS-232 menu."
    PRINT
    DO
        INPUT "   ***  Press (1) to use COM1 or (2) for COM2 >", port$
    LOOP UNTIL (port$ = "1" OR port$ = "2")

    SCOPE% = 1
    OPEN "COM" + port$ + ":9600,N,8,1" FOR RANDOM AS #SCOPE%
'
'  Clear the device and check for errors
'
    CALL SENDBREAK(SCOPE%, VAL(port$))
'
'  Clear any existing menus, then run the factory initialization
'
    CALL RS232WRITE(SCOPE%, "CLEARMENU")
    CALL RS232WRITE(SCOPE%, "FACTORY")
'
'  Print a message on the screen instructing the user to connect Channel 1
'  to the test signal.
'
        CLS
        PRINT : PRINT "        TDS 200 Series COMM Program - Version 1.2"
        PRINT : PRINT
        PRINT "   ***  Connect your test signal to Channel 1  ***"
        PRINT
        PRINT "        For example, you might connect the PROBE COMP signal"
        PRINT "        to the Channel 1 input connector using a 10X probe."
        PRINT
        PRINT "   ***  Press any key when done  ";
        ANS$ = INPUT$(1)
'
'  Wait for the scope to finish the factory command.
'
    CALL RS232WAITCOM(SCOPE%, 2)
'
'  Turn off the header from query responses.
'
    CALL RS232WRITE(SCOPE%, "HEADER OFF")
'
'  Send the autoset command to display the calibrator signal.
'
    CALL RS232WRITE(SCOPE%, "AUTOSET EXECUTE")
    PRINT : PRINT : PRINT
    PRINT "	An autoset of the Channel 1 waveform is now being performed"
'
'  Query the oscilloscope for its selected VOLTS/DIV setting and TIME/DIV
'  setting.
'
    CALL RS232WRITE(SCOPE%, "CH1:SCALE?")
    CALL RS232READ(SCOPE%, VOLTS$)
   
    CALL RS232WRITE(SCOPE%, "HORIZONTAL:MAIN:SCALE?")
    CALL RS232READ(SCOPE%, SEC$)
'
'  Display results.
'
    PRINT : PRINT
    PRINT "	The VOLTS/DIV setting is "; VOLTS$
    PRINT "	The  SEC/DIV  setting is "; SEC$
    PRINT
'
'  Deallocate buffers and close communications.
'
    CLOSE #SCOPE%
    END

