'
'  getwfm.bas - program to get a waveform from an oscilloscope,
'               convert its data values to absolute voltage measurements,
'               and store these values in a Lotus 123 compatible file.
'
' Version 1.2.
'
'REM $INCLUDE: 'decl.bas'
'
'  Allocate the buffers and initialize the port for input and output.
'  Avoid input buffer overflow on slow machines by setting buffer size
'  to 2500 bytes.  Assign a unique identifier to the port and store
'  in variable SCOPE.
'
    CLS
    PRINT : PRINT "        TDS 200 Series GETWFM Program - Version 1.2"
    PRINT : PRINT
    PRINT "   ***  RS-232 parameters should be set to default values:"
    PRINT
    PRINT "          Baud Rate: 9600      EOL: LF        Delay: 0 s"
    PRINT "          Hard Flagging: On    Parity: None"
    PRINT "          Soft Flagging: Off   Stop Bits: 1"
    PRINT
    PRINT "        These parameters can be changed in the "
    PRINT "        UTILITY  System - I/O  RS-232 menu."
    PRINT
    DO
	INPUT "   ***  Press (1) to use COM1 or (2) for COM2 >", port$
    LOOP UNTIL (port$ = "1" OR port$ = "2")
    
    SCOPE% = 1
    OPEN "COM" + port$ + ":9600,N,8,1,RB2500" FOR RANDOM AS #SCOPE%
'
'  Clear the device and check for errors
'
    CALL SENDBREAK(SCOPE%, VAL(port$))
'
'  Turn off the header from query responses.
'
	CALL RS232WRITE(SCOPE%, "HEADER OFF")
'
'  Set up the data source to be channel 1.
'
	DATSRC$ = "CH1"
	WRT$ = "DATA:SOURCE " + DATSRC$
	CALL RS232WRITE(SCOPE%, WRT$)
'
'  Set up data encoding to be ribinary and data width to 1.
'
	CALL RS232WRITE(SCOPE%, "DATA:ENCDG RIBINARY;WIDTH 1")
'
'  Print a message on the screen instructing the user to connect Channel 1
'  to the test signal.
'
	CLS
	PRINT : PRINT "        TDS 200 Series GETWFM Program - Version 1.2"
	PRINT : PRINT
	PRINT "   ***  Connect your test signal to Channel 1  ***"
	PRINT
	PRINT "        For example, you might connect the PROBE COMP signal"
	PRINT "        to the Channel 1 input connector using a 10X probe."
	PRINT
	PRINT "   ***  Press any key when done  ";
	ANS$ = INPUT$(1)
'
'  Set up the recordlength, and the data start and data stop positions.
'  In this example, the entire waveform is obtained so data start and
'  data stop are 1 and 2500 respectively.
'
	RL% = 2500
	WRT$ = "HORIZONTAL:RECORDLENGTH " + STR$(RL%)
	CALL RS232WRITE(SCOPE%, WRT$)
	
	DSTART% = 1
	DSTOP% = RL%
	WFPOINTS% = DSTOP% - DSTART% + 1
	PRINT : PRINT : PRINT
	PRINT "        Number of waveform points is "; WFPOINTS%
	PRINT
	
	WRT$ = "DATA:START " + STR$(DSTART%)
	CALL RS232WRITE(SCOPE%, WRT$)
	
	WRT$ = "DATA:STOP " + STR$(DSTOP%)
	CALL RS232WRITE(SCOPE%, WRT$)
 
	WRT$ = "HEADER OFF"
	CALL RS232WRITE(SCOPE%, WRT$)
'
'  Make sure setup changes have taken effect and a new waveform is acquired
'
	CALL RS232WRITE(SCOPE%, "ACQUIRE:STATE RUN")
'
'  Wait for the scope to acquire the waveform.
'
	CALL RS232WAITCOM(SCOPE%, 10)
'
'  Send the scope a curve query to get waveform data.
'
	CALL RS232WRITE(SCOPE%, "CURVE?")
'
' Read waveform data into a string.
'
	CALL RS232READ(SCOPE%, WFM$)
'
'  Transfer waveform data into an array.  There is one data point
'  stored in each array element.
'
	DIM WFARR%(1 TO WFPOINTS%)    ' set up the waveform output array
	FOR I% = 1 TO WFPOINTS%
	    WFARR%(I%) = ASC(MID$(WFM$, I%, 1))
	    IF WFARR%(I%) > 127 THEN WFARR%(I%) = WFARR%(I%) - 256
	NEXT I%
'
'  Read the waveform preamble.
'  Get the vertical offset and scale multiplier,
'  the trigger point, the horizontal sampling interval
'  and the horizontal units to convert the data points to
'  time and voltage values.
'
	WRT$ = "WFMPRE:" + DATSRC$ + ":YOFF?"
	CALL RS232WRITE(SCOPE%, WRT$)
	CALL RS232READ(SCOPE%, rd$)
	YOFF! = VAL(rd$)
	
	WRT$ = "WFMPRE:" + DATSRC$ + ":YMULT?"
	CALL RS232WRITE(SCOPE%, WRT$)
	CALL RS232READ(SCOPE%, rd$)
	YMULT! = VAL(rd$)

	WRT$ = "WFMPRE:" + DATSRC$ + ":YUNIT?"
	CALL RS232WRITE(SCOPE%, WRT$)
	CALL RS232READ(SCOPE%, YUNIT$)

	WRT$ = "WFMPRE:" + DATSRC$ + ":XZERO?"
	CALL RS232WRITE(SCOPE%, WRT$)
	CALL RS232READ(SCOPE%, rd$)
	XZERO! = VAL(rd$)

	WRT$ = "WFMPRE:" + DATSRC$ + ":XINCR?"
	CALL RS232WRITE(SCOPE%, WRT$)
	CALL RS232READ(SCOPE%, rd$)
	XINCR! = VAL(rd$)

	WRT$ = "WFMPRE:" + DATSRC$ + ":XUNIT?"
	CALL RS232WRITE(SCOPE%, WRT$)
	CALL RS232READ(SCOPE%, XUNIT$)
'
'       Output header (x-, y-units, date, time and source)
'       Write out the data to a file called "WFM_DATA.PRN".
'
	WAVEFL$ = "WFM_DATA.PRN"         ' set up an output file for the data time and voltages
	OPEN WAVEFL$ FOR OUTPUT AS #2
	PRINT #2, XUNIT$; ","; YUNIT$
	WRITE #2, DATE$, TIME$, "CH1"
'
'       Process waveform data.
'       Write out the data to a file called "WFM_DATA.PRN".
'
	DIM VOLTARR!(1 TO WFPOINTS%) ' set up the voltage output array
	DIM TIMEARR!(1 TO WFPOINTS%) ' set up the time output array
	FOR I% = 1 TO WFPOINTS%
		TIMEARR!(I%) = XZERO! + (I% * XINCR!)
		VOLTARR!(I%) = (WFARR%(I%) - YOFF!) * YMULT!
		PRINT #2, TIMEARR!(I%), VOLTARR!(I%)
	NEXT I%
'
'       Final message
'
	PRINT "        Waveform time and voltage points are in file ";
	PRINT WAVEFL$
	PRINT
'
'  Deallocate buffers and close communications.
'
	CLOSE #SCOPE%
	END

